@@ -19,17 +19,24 @@ from .vecteurs import *
 from .chaines import *
 from .listes import *
 
+print("""
+Merci d'utiliser la librairie lycee du module pydiderot.\n
+N'hésitez pas à consulter la documentation en ligne:\n
+https://pydiderotlibs.rtfd.io/librairies/lycee.html
+""")
+
 pi = math.pi
 
 
 def repeter(f, n):
-    """ Appelle `n` fois la fonction ``f``.
+    """ 
+    Appelle `n` fois la fonction ``f``.
 
     Alias disponible: ``repeat()``
     """
     for i in range(n):
         f()
 
-
 def repeat(f, n):
     repeter(f, n)
+    
