@@ -8,10 +8,18 @@ from tkinter import Tk, Canvas, N, E, RIDGE, LEFT, BOTH, YES, NE, LAST
 from math import floor
 from .couleurs import rgb, rgb2hex
 
-global fenetre
+# Un petit message invitant a lire la doc
+print("""
+Merci d'utiliser la librairie repere du module pydiderot.\n
+N'hésitez pas à consulter la documentation en ligne:\n
+https://pydiderotlibs.rtfd.io/librairies/repere.html
+""")
+
+# On définit la variable globale _fenetre
+_fenetre = None
 
 
-class _Fenetre_graphique(Canvas):
+class _FenetreGraphique(Canvas):
     " Un canvas redimensionnable, avec repère usuel, zoomable... "
     # les coordonnées en pixels sont à l'intérieur du canvas (sans le bord)
     # R1 : repère lié aux pixels, B1 sa base associée
@@ -23,7 +31,8 @@ class _Fenetre_graphique(Canvas):
         Canvas.__init__(self, boss)
         self.configure(width=largeur, height=hauteur,
                        bg=background, border=5, relief=RIDGE)
-
+        self.x1 = 0
+        self.y2 = 0
         self.axes = axes
         self.xmin, self.ymin, self.xmax, self.ymax = xmin, ymin, xmax, ymax
         self.largeur = largeur  # int(self.cget('width'))
@@ -304,18 +313,10 @@ class _Fenetre_graphique(Canvas):
         # self.master.quit()
         self.master.destroy()
 
-    def _trace_point(self, tab):
-        pt = self._conv(self.objets[i][2], self.objets[i][3])
-
-        self.objets[i][0] = self.create_oval(pt[0] - coef * taille, pt[1] - coef * taille,
-                                             pt[0] + coef *
-                                             taille, pt[1] + coef * taille,
-                                             outline='', fill=self.objets[i][4])
-
     def loop(self):
         self.master.mainloop()
 
-################################## Fin de la classe _Fenetre_graphique ###
+################################## Fin de la classe _FenetreGraphique ###
 
 
 def trace_point(x, y, couleur='noir', taille=1, forme='rond'):
@@ -330,27 +331,27 @@ def point(x, y, couleur='noir', taille=1, forme='rond'):
     Arguments:
         x (float): abscisse du point
         y (float): ordonnée du point
-        couleur (`couleur <#couleurs>`_, optionel): couleur du point (``noir`` par défaut)
-        taille (int, optionel): taille du point (``1`` par défaut)
-        forme (str, optionel): forme du point: rond/croix (``'rond'`` par défaut)
+        couleur (`couleur <#couleurs>`_, optionnel): couleur du point (``noir`` par défaut)
+        taille (int, optionnel): taille du point (``1`` par défaut)
+        forme (str, optionnel): forme du point: rond/croix (``'rond'`` par défaut)
     """
 
     couleur = rgb2hex(rgb(couleur))
-    global fenetre
+    global _fenetre
     coef = 2
-    pt = fenetre._conv(x, y)
+    pt = _fenetre._conv(x, y)
     tab = [0] * 8
     if forme == 'rond':
-        tab[0] = fenetre.create_oval(pt[0] - coef * taille, pt[1] - coef * taille,
+        tab[0] = _fenetre.create_oval(pt[0] - coef * taille, pt[1] - coef * taille,
                                      pt[0] + coef * taille, pt[1] +
                                      coef * taille,
                                      outline='', fill=couleur)
     elif forme == 'croix':
-        tab[0] = fenetre.create_line(pt[0] - coef * taille, pt[1] - coef * taille,
+        tab[0] = _fenetre.create_line(pt[0] - coef * taille, pt[1] - coef * taille,
                                      pt[0] + coef * taille, pt[1] +
                                      coef * taille,
                                      fill=couleur)
-        tab[7] = fenetre.create_line(pt[0] - coef * taille, pt[1] + coef * taille,
+        tab[7] = _fenetre.create_line(pt[0] - coef * taille, pt[1] + coef * taille,
                                      pt[0] + coef * taille, pt[1] -
                                      coef * taille,
                                      fill=couleur)
@@ -361,7 +362,7 @@ def point(x, y, couleur='noir', taille=1, forme='rond'):
     tab[4] = couleur
     tab[5] = taille
     tab[6] = forme
-    fenetre.objets.append(tab)
+    _fenetre.objets.append(tab)
 
 
 def trace_texte(x, y, message, couleur='noir'):
@@ -381,20 +382,20 @@ def texte(x, y, message, couleur='noir'):
         x (float): abscisse du point
         y (float): ordonnée du point
         message (str): Texte à placer dans la fenêtre graphique
-        couleur (`couleur <#couleurs>`_, optionel): Couleur du texte (``noir`` par défaut)
+        couleur (`couleur <#couleurs>`_, optionnel): Couleur du texte (``noir`` par défaut)
 
     """
     couleur = rgb2hex(rgb(couleur))
 
-    global fenetre
+    global _fenetre
     tab = [0] * 6
-    tab[0] = fenetre.create_text(x, y, text=texte, fill=couleur)
+    tab[0] = _fenetre.create_text(x, y, text=texte, fill=couleur)
     tab[1] = 'texte'
     tab[2] = x
     tab[3] = y
     tab[4] = message
     tab[5] = couleur
-    fenetre.objets.append(tab)
+    _fenetre.objets.append(tab)
 
 
 def trace_segment(x1, y1, x2, y2, couleur='noir', taille=2):
@@ -408,17 +409,17 @@ def segment(x1, y1, x2, y2, couleur='noir', taille=2):
 
     Arguments:
         x1,y1,x2,y2 (float): Coordonées des extrémités du segment.
-        couleur (`couleur <#couleurs>`_, optionel): Couleur du segment (``noir`` par défaut).
+        couleur (`couleur <#couleurs>`_, optionnel): Couleur du segment (``noir`` par défaut).
         taille (int, optionl): Epaisseur du segment (``2`` par défaut).
         """
     couleur = rgb2hex(rgb(couleur))
 
-    global fenetre
+    global _fenetre
 
     tab = [0] * 8
-    tab[0] = fenetre.create_line(
-        fenetre._conv(
-            x1, y1), fenetre._conv(
+    tab[0] = _fenetre.create_line(
+        _fenetre._conv(
+            x1, y1), _fenetre._conv(
             x2, y2), width=taille, fill=couleur)
     tab[1] = 'segment'
     tab[2] = x1
@@ -427,7 +428,7 @@ def segment(x1, y1, x2, y2, couleur='noir', taille=2):
     tab[5] = y2
     tab[6] = couleur
     tab[7] = taille
-    fenetre.objets.append(tab)
+    _fenetre.objets.append(tab)
 
 
 def trace_rectangle(x1, y1, largeur, hauteur, couleur='noir',
@@ -444,18 +445,18 @@ def rectangle(x1, y1, largeur, hauteur, couleur='noir',
     Arguments:
         x1,y1 (float): Coordonnées du sommet en bas à gauche du rectangle.
         largeur,hauteur (float): Largeur et hauteur du rectangle
-        couleur (`couleur <#couleurs>`_, optionel): Couleur des cotés du rectangle (``noir`` par défaut).
-        taille (int, optionel): épaisseur des cotés du rectangle. ( ``2`` par défaut).
-        remplissage (str, optionel): Couleur de l'intérieur du rectangle (``yellow`` par default)
+        couleur (`couleur <#couleurs>`_, optionnel): Couleur des cotés du rectangle (``noir`` par défaut).
+        taille (int, optionnel): épaisseur des cotés du rectangle. ( ``2`` par défaut).
+        remplissage (str, optionnel): Couleur de l'intérieur du rectangle (``yellow`` par default)
     """
 
     couleur = rgb2hex(rgb(couleur))
     remplissage = rgb2hex(rgb(remplissage))
 
-    global fenetre
+    global _fenetre
 
     tab = [0] * 9
-    tab[0] = fenetre.create_rectangle(fenetre._conv(x1, y1), fenetre._conv(x1 + largeur, y1 + hauteur),
+    tab[0] = _fenetre.create_rectangle(_fenetre._conv(x1, y1), _fenetre._conv(x1 + largeur, y1 + hauteur),
                                       outline=couleur, width=taille, fill=remplissage)
     tab[1] = 'rectangle'
     tab[2] = x1
@@ -465,7 +466,7 @@ def rectangle(x1, y1, largeur, hauteur, couleur='noir',
     tab[6] = couleur
     tab[7] = taille
     tab[8] = remplissage
-    fenetre.objets.append(tab)
+    _fenetre.objets.append(tab)
 
 
 ### Fonction principale pour demarrer ####
@@ -483,22 +484,22 @@ def fenetre(xmin=-10, xmax=10, ymin=-10, ymax=10, fond='blanc',
             titre="Repère mathematique", axes=True):
     """Initialise l'object fenetre graphique sans l'afficher.
 
-    Alias: ``trace_fenetre()`` et ``window()``
+    Alias: ``creer_fenetre()`` et ``window()``
 
     Arguments:
         titre (str): Titre de la fenêtre. La valeur par défaut est ``Repère mathematique``.
         xmin,xmax,ymin,ymax (float) : Dimensions du repère. Les valeurs par défaut sont -10, 10, -10, 10
-        fond (`couleur <#couleurs>`_, optionel): Couleur de fond de la fenêtre (``blanc`` par défaut).
-        axes (bool, optionel): Affiche les axes du repère si ``True`` (``True`` par défaut).
+        fond (`couleur <#couleurs>`_, optionnel): Couleur de fond de la fenêtre (``blanc`` par défaut).
+        axes (bool, optionnel): Affiche les axes du repère si ``True`` (``True`` par défaut).
     """
 
     fond = rgb2hex(rgb(fond))
 
     root = Tk()       # on crée la fenêtre
     root.title(titre)  # on lui donne un titre
-    graph = _Fenetre_graphique(root, xmin=xmin, xmax=xmax, ymin=ymin, ymax=ymax,
+    graph = _FenetreGraphique(root, xmin=xmin, xmax=xmax, ymin=ymin, ymax=ymax,
                                background=fond, axes=axes)
     graph.pack(side=LEFT, fill=BOTH, expand=YES)
-    global fenetre
-    fenetre = graph
+    global _fenetre
+    _fenetre = graph
     return graph
